@@ -5,6 +5,7 @@ import warnings
 import sqlalchemy
 from sqlalchemy.engine import create_engine
 from sqlalchemy import MetaData, Table
+from converter.vertica.custom_insert import vertica_insert
 
 warnings.filterwarnings("ignore")
 
@@ -44,7 +45,7 @@ def get_default_arg_sql_alchemy(column):
 
 class DataBaseWorker:
     def __init__(
-            self, sql_credentials, db, debug=True, tables=None, table_checker=True
+        self, sql_credentials, db, debug=True, tables=None, table_checker=True
     ):
         """
         :param sql_credentials:
@@ -154,6 +155,24 @@ class DataBaseWorker:
             )
         return True
 
+    def insert_vertica(self, table_name, data):
+        """
+        custom insert for vertica using json
+        :param table_name:
+        :param data: data to insert
+        :return:
+        """
+        cursor = self.engine.raw_connection().cursor()
+        columns = self.get_columns(table_name)
+        fields_json = [key for key in columns if columns[key] == "long varbinary"]
+        vertica_insert(
+            cursor=cursor,
+            target=self.schema + "." + table_name,
+            fields_json=fields_json,
+            fields=list(columns.keys()),
+            data=data,
+        )
+
     def get_table_schema(self, table_name):
         columns_name = [
             "column_name",
